@@ -113,7 +113,7 @@ void sequencer(VPN *anchor)
 
 			/* execute linkup process, if there is any */
 
-			doexec(anchor->linkup);
+			doexec(anchor->linkup,NULL);
 
 			/* while select returns no serial line exception */
 
@@ -161,7 +161,7 @@ void sequencer(VPN *anchor)
 					/* execute linkdown process,
 					   if there is any */
 
-					doexec(anchor->linkdown);
+					doexec(anchor->linkdown,NULL);
 					goto perr3;
 				}
 			}
@@ -382,7 +382,7 @@ perr1:			sleep(anchor->retry);
 						/* execute linkup process,
 						   if there is any */
 
-						doexec(anchor->linkup);
+						doexec(anchor->linkup,NULL);
 					}
 				}
 			}
@@ -607,7 +607,7 @@ perr1:			sleep(anchor->retry);
 						/* execute linkup process
 						   if there is any */
 
-						doexec(anchor->linkup);
+						doexec(anchor->linkup,NULL);
 					}
 				}
 			}
@@ -798,7 +798,7 @@ perr1:			sleep(anchor->retry);
 						/* execute linkup process,
 						   if there is any */
 
-						doexec(anchor->linkup);
+						doexec(anchor->linkup,NULL);
 					}
 				}
 
